@@ -2,7 +2,7 @@ extern crate serde_json;
 extern crate ureq;
 
 use super::Candle;
-use crate::{client::Client, helpers::get_response};
+use crate::client::Client;
 use serde::{Deserialize, Serialize};
 use std::io::{self, Error, ErrorKind};
 
@@ -20,14 +20,13 @@ pub struct PrevResponse {
 }
 
 impl Client {
-  pub fn get_prev(&self, symbol: &str) -> io::Result<PrevResponse> {
+  pub fn get_prev(&mut self, symbol: &str) -> io::Result<PrevResponse> {
     let uri = format!(
       "{}/v2/aggs/ticker/{}/prev?apikey={}",
       self.api_uri, symbol, self.key
     );
 
-    let resp = get_response(&self.agent.agent, &uri)?;
-    let mut resp = resp.into_json::<PrevResponse>()?;
+    let mut resp = self.get_response::<PrevResponse>(&uri)?;
     resp.uri = Some(uri);
 
     if resp.results.len() != 1 {
@@ -56,7 +55,7 @@ mod prev {
 
   #[test]
   fn works() {
-    let client = Client::new();
+    let mut client = Client::new();
     let prev = client.get_prev("AAPL").unwrap();
     assert_eq!(prev.results.len(), 1);
   }
