@@ -37,14 +37,13 @@ pub struct DividendsResponse {
 }
 
 impl Client {
-  pub fn get_dividends(&self, symbol: &str) -> std::io::Result<DividendsResponse> {
+  pub fn get_dividends(&mut self, symbol: &str) -> std::io::Result<DividendsResponse> {
     let uri = format!(
       "{}/v2/reference/dividends/{}?apikey={}",
       self.api_uri, symbol, self.key
     );
 
-    let resp = get_response(&self.agent.agent, &uri)?;
-    let resp = resp.into_json::<DividendsResponse>()?;
+    let resp = self.get_response::<DividendsResponse>(&uri)?;
 
     Ok(resp)
   }
@@ -56,7 +55,7 @@ mod dividends {
 
   #[test]
   fn works() {
-    let client = Client::new();
+    let mut client = Client::new();
     let splits = client.get_dividends("AAPL").unwrap();
     assert!(splits.results.len() > 60);
   }
