@@ -1,7 +1,7 @@
 extern crate serde_json;
 extern crate ureq;
 
-use crate::{client::Client, helpers::get_response};
+use crate::client::Client;
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Deserialize, Serialize)]
@@ -19,11 +19,10 @@ pub struct LocalesResponse {
 }
 
 impl Client {
-  pub fn get_locales(&self) -> std::io::Result<LocalesResponse> {
+  pub fn get_locales(&mut self) -> std::io::Result<LocalesResponse> {
     let uri = format!("{}/v2/reference/locales?apikey={}", self.api_uri, self.key);
 
-    let resp = get_response(&self.agent.agent, &uri)?;
-    let resp = resp.into_json::<LocalesResponse>()?;
+    let resp = self.get_response::<LocalesResponse>(&uri)?;
 
     Ok(resp)
   }
@@ -35,7 +34,7 @@ mod locales {
 
   #[test]
   fn works() {
-    let client = Client::new();
+    let mut client = Client::new();
     let locales = client.get_locales().unwrap();
     assert!(locales.results.len() > 17);
     assert!(locales
