@@ -1,7 +1,7 @@
 extern crate serde_json;
 extern crate ureq;
 
-use crate::{client::Client, helpers::get_response};
+use crate::client::Client;
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Deserialize, Serialize)]
@@ -19,11 +19,10 @@ pub struct MarketsResponse {
 }
 
 impl Client {
-  pub fn get_markets(&self) -> std::io::Result<MarketsResponse> {
+  pub fn get_markets(&mut self) -> std::io::Result<MarketsResponse> {
     let uri = format!("{}/v2/reference/markets?apikey={}", self.api_uri, self.key);
 
-    let resp = get_response(&self.agent.agent, &uri)?;
-    let resp = resp.into_json::<MarketsResponse>()?;
+    let resp = self.get_response::<MarketsResponse>(&uri)?;
 
     Ok(resp)
   }
@@ -35,7 +34,7 @@ mod markets {
 
   #[test]
   fn works() {
-    let client = Client::new();
+    let mut client = Client::new();
     let markets = client.get_markets().unwrap();
     assert!(markets
       .results
