@@ -1,7 +1,7 @@
 extern crate serde_json;
 extern crate ureq;
 
-use crate::{client::Client, helpers::get_response};
+use crate::client::Client;
 use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 
@@ -20,11 +20,10 @@ pub struct TypesResponse {
 }
 
 impl Client {
-  pub fn get_types(&self) -> std::io::Result<TypesResponse> {
+  pub fn get_types(&mut self) -> std::io::Result<TypesResponse> {
     let uri = format!("{}/v2/reference/types?apikey={}", self.api_uri, self.key);
 
-    let resp = get_response(&self.agent.agent, &uri)?;
-    let resp = resp.into_json::<TypesResponse>()?;
+    let resp = self.get_response::<TypesResponse>(&uri)?;
 
     Ok(resp)
   }
@@ -36,7 +35,7 @@ mod types {
 
   #[test]
   fn works() {
-    let client = Client::new();
+    let mut client = Client::new();
     let types = client.get_types().unwrap();
     assert_eq!(
       types.results.types.get("CS").unwrap(),
